summaryrefslogtreecommitdiffstats
path: root/kpilot/lib/syncAction.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/lib/syncAction.h')
-rw-r--r--kpilot/lib/syncAction.h56
1 files changed, 28 insertions, 28 deletions
diff --git a/kpilot/lib/syncAction.h b/kpilot/lib/syncAction.h
index a93bff99..4643e7c6 100644
--- a/kpilot/lib/syncAction.h
+++ b/kpilot/lib/syncAction.h
@@ -33,9 +33,9 @@
#include <pi-dlp.h>
-#include <qobject.h>
-#include <qstring.h>
-#include <qstringlist.h>
+#include <tqobject.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
#include "kpilotlink.h"
@@ -55,7 +55,7 @@ public:
SyncAction(KPilotLink *p,
const char *name=0L);
SyncAction(KPilotLink *p,
- QWidget *visibleparent,
+ TQWidget *visibleparent,
const char *name=0L);
~SyncAction();
@@ -70,7 +70,7 @@ public:
return fActionStatus;
}
/** Return a human-readable representation of the status. */
- virtual QString statusString() const;
+ virtual TQString statusString() const;
protected:
/**
@@ -97,9 +97,9 @@ public slots:
signals:
void syncDone(SyncAction *);
- void logMessage(const QString &);
- void logError(const QString &);
- void logProgress(const QString &,int);
+ void logMessage(const TQString &);
+ void logError(const TQString &);
+ void logProgress(const TQString &,int);
protected slots:
/** This slot emits syncDone(), and does nothing else. This
@@ -128,7 +128,7 @@ public:
* @note Having messages appear on the handheld but not in KPilot
* should be a @em very rare occurrence.
*/
- void addSyncLogEntry(const QString &e,bool log=true)
+ void addSyncLogEntry(const TQString &e,bool log=true)
{
if (deviceLink())
{
@@ -138,17 +138,17 @@ public:
/** Public API for adding a message to the log in KPilot.
* Adds @p msg to the synclog maintained on the PC.
*/
- void addLogMessage( const QString &msg )
+ void addLogMessage( const TQString &msg )
{
emit logMessage( msg );
}
/** Log an error message in KPilot (the PC side of things). */
- void addLogError( const QString &msg )
+ void addLogError( const TQString &msg )
{
emit logError( msg );
}
/** Log progress in KPilot (the PC side of things). */
- void addLogProgress( const QString &msg, int prog )
+ void addLogProgress( const TQString &msg, int prog )
{
emit logProgress( msg, prog );
}
@@ -217,7 +217,7 @@ public:
* a string list to pass aparameters to the shared
* library loader.
*/
- SyncMode(const QStringList &l);
+ SyncMode(const TQStringList &l);
/** Returns the kind of sync; this is just incomplete
* information, since a test hot sync is very different from
@@ -311,20 +311,20 @@ public:
/**
* Returns a standard name for each of the sync modes.
*/
- static QString name(Mode);
+ static TQString name(Mode);
/**
* Returns a (human readable) name for this particular mode,
* including extra information about test and local mode.
*/
- QString name() const;
+ TQString name() const;
/**
* Returns a QStringList that, when passed to the constructor
* of SyncMode, will re-create it. Used to pass modes into
* shared library factories.
*/
- QStringList list() const;
+ TQStringList list() const;
private:
Mode fMode;
@@ -378,7 +378,7 @@ signals:
protected:
- QWidget *fParent;
+ TQWidget *fParent;
/**
* Ask a yes-no question of the user. This has a timeout so that
@@ -392,18 +392,18 @@ protected:
* @p key Key for the "Don't ask again" code.
* @p timeout Timeout, in seconds.
*/
- int questionYesNo(const QString &question ,
- const QString &caption = QString::null,
- const QString &key = QString::null,
+ int questionYesNo(const TQString &question ,
+ const TQString &caption = TQString::null,
+ const TQString &key = TQString::null,
unsigned timeout = 20,
- const QString &yes = QString::null,
- const QString &no = QString::null );
- int questionYesNoCancel(const QString &question ,
- const QString &caption = QString::null,
- const QString &key = QString::null,
+ const TQString &yes = TQString::null,
+ const TQString &no = TQString::null );
+ int questionYesNoCancel(const TQString &question ,
+ const TQString &caption = TQString::null,
+ const TQString &key = TQString::null,
unsigned timeout = 20,
- const QString &yes = QString::null,
- const QString &no = QString::null ) ;
+ const TQString &yes = TQString::null,
+ const TQString &no = TQString::null ) ;
};
@@ -311,20 +311,20 @@ public:
/**
- * Returns a QStringList that, when passed to the constructor
+ * Returns a TQStringList that, when passed to the constructor
* of SyncMode, will re-create it. Used to pass modes into
* shared library factories.